<?php 
namespace App\Controllers;
use App\Models\UserModel;
use CodeIgniter\Controller;
use CodeIgniter\Email\Email;

class AuthController extends Controller {
    protected $userModel;

    public function __construct() {
        $this->userModel = new UserModel();
    }

    // Registration Form
    public function register() {
        return view('auth/register');
    }

    // Handle Registration
    public function registerUser() {
        $email = $this->request->getPost('email');
        $password = password_hash($this->request->getPost('password'), PASSWORD_DEFAULT);

        // Check if email exists
        if ($this->userModel->where('email', $email)->first()) {
            return redirect()->back()->with('error', 'Email already registered.');
        }

        // Save user
        $this->userModel->insert(['email' => $email, 'password' => $password]);

        return redirect()->to('/login')->with('success', 'Registered successfully! Please login.');
    }

    // Login Form
    public function login() {
        $session = session();

        // Auto-login using Remember Token
        if (isset($_COOKIE['remember_token'])) {
            $user = $this->userModel->where('remember_token', $_COOKIE['remember_token'])->first();
            if ($user) {
                $session->set('user_id', $user['id']);
                return redirect()->to('/dashboard');
            }
        }

        return view('auth/login');
    }

    // Handle Login and Send OTP
    public function sendOTP() {
        $session = session();
        $email = $this->request->getPost('email');
        $password = $this->request->getPost('password');
    
        // Find user by email
        $user = $this->userModel
        ->where('email', $email)
        ->where('password', $password)
        ->first();
    
        // Check if user exists and verify password
        if (!$user) {
            return redirect()->to('/login')->with('error', 'Invalid email or password.');
        }
    
        // Generate OTP
        $otp = rand(100000, 999999);
        $expiry = date('Y-m-d H:i:s', strtotime('+5 minutes'));
    
        // Save OTP in database
        $this->userModel->update($user['id'], ['otp' => $otp, 'otp_expiry' => $expiry]);
    
        // Store email in session
        $session->set('otp_email', $email);
    
        // Send OTP Email
        if ($this->sendEmailOTP($email, $otp)) {
            return redirect()->to('/verify-otp')->with('success', 'OTP has been sent to your email.');
        } else {
            return redirect()->back()->with('error', 'Failed to send OTP. Please try again.');
        }
    }
    

    // Verify OTP Form
    public function verifyOTPForm() {
        return view('auth/verify_otp');
    }

    // Verify OTP and Log in User
    public function verifyOTP()
{
    $session = session();
    $email = $session->get('otp_email');

    if (!$email) {
        return redirect()->to('/login')->with('error', 'Session expired, please log in again.');
    }

    $user = $this->userModel->where('email', $email)->first();

    if (!$user) {
        return redirect()->to('/login')->with('error', 'User not found.');
    }

    // Check OTP
    $otpInput = implode("", $this->request->getPost('otp'));
    if (!$user['otp'] || (string) $user['otp'] !== (string) $otpInput) {
        return redirect()->back()->with('error', 'Invalid OTP.');
    }

    if (strtotime($user['otp_expiry']) < time()) {
        return redirect()->back()->with('error', 'OTP expired. Request a new one.');
    }

    // Clear OTP after successful verification
    $this->userModel->update($user['id'], ['otp' => null, 'otp_expiry' => null]);

    // ✅ Set session to keep user logged in for 3 days
    $session->set([
        'user_id' => $user['id'],
        'email' => $user['email'],
        'is_logged_in' => true,
        'expire' => time() + (3 * 24 * 60 * 60) // 3 days
    ]);

    return redirect()->to('/dashboard')->with('success', 'OTP Verified Successfully!');
}


    // Resend OTP
    public function resendOTP() {
        $session = session();
        $email = $session->get('otp_email');
    
        if (!$email) {
            return redirect()->back()->with('error', 'Invalid session. Please login again.');
        }
    
        $user = $this->userModel->where('email', $email)->first();
    
        if (!$user) {
            return redirect()->back()->with('error', 'User not found.');
        }
    
        // Generate new OTP
        $otp = rand(100000, 999999);
        $expiry = date('Y-m-d H:i:s', strtotime('+5 minutes'));
    
        // Update OTP in the database
        $this->userModel->update($user['id'], ['otp' => $otp, 'otp_expiry' => $expiry]);
    
        // Send OTP email
        $this->sendEmailOTP($email, $otp);
    
        return redirect()->back()->with('success', 'A new OTP has been sent.');
    }
    

    // Logout
    public function logout() {
        $session = session();

        if (isset($_COOKIE['remember_token'])) {
            $this->userModel->where('remember_token', $_COOKIE['remember_token'])->set(['remember_token' => null])->update();
            setcookie('remember_token', '', time() - 3600, "/", "", false, true);
        }

        $session->destroy();
        return redirect()->to('/login');
    }

   private function sendEmailOTP($email, $otp) {
    $emailService = \Config\Services::email();

   $emailService->initialize([
    'protocol'   => 'smtp',
    'SMTPHost'   => getenv('EMAIL_SMTP_HOST'),
    'SMTPUser'   => getenv('EMAIL_SMTP_USER'),
    'SMTPPass'   => getenv('EMAIL_SMTP_PASS'),
    'SMTPPort'   => (int) getenv('EMAIL_SMTP_PORT'), // Explicit casting
    'SMTPCrypto' => getenv('EMAIL_SMTP_CRYPTO'),  
    'mailType'   => 'html',
    'charset'    => 'utf-8',
    'wordWrap'   => true
]);

    $emailService->setFrom(getenv('EMAIL_FROM'), getenv('EMAIL_NAME'));
    $emailService->setTo($email);
    $emailService->setSubject('Your OTP Code');
    $emailService->setMessage(view('emails/otp_email', ['otp' => $otp]));

    if (!$emailService->send()) {
        log_message('error', 'Email sending failed: ' . $emailService->printDebugger(['headers']));
        return false;
    }

    log_message('info', 'OTP email sent successfully to: ' . $email);
    return true;
}


}
