<?php

namespace App\Controllers;

use CodeIgniter\RESTful\ResourceController;
use App\Models\EnquiryModel;

class EnquiryController extends ResourceController
{
    protected $format = 'json';

    // Submit an Enquiry
    public function submitEnquiry()
    {
        $enquiryModel = new EnquiryModel();

        // Get request data
        $data = [
            'full_name' => $this->request->getVar('full_name'),
            'phone_no'  => $this->request->getVar('phone_no'),
            'email'     => $this->request->getVar('email'),
            'message'   => $this->request->getVar('message'),
            'ip'        => $this->request->getIPAddress(),
            'platform'  => $this->request->getVar('platform'),
            'browser'   => $this->request->getUserAgent()->getBrowser(),
            'user_agent' => $this->request->getUserAgent()->getAgentString(),
        ];

        if ($enquiryModel->insert($data)) {
            return $this->respondCreated([
                'status'  => 'success',
                'message' => 'Your Message is submitted successfully!',
                'data'    => $data
            ]);
        }

        return $this->fail('Failed to submit enquiry.');
    }

    // Get All Enquiries
    public function getAllEnquiries()
    {
        $enquiryModel = new EnquiryModel();
        $enquiries = $enquiryModel->orderBy('id', 'DESC')->findAll();

        return $this->respond([
            'status' => 'success',
            'data'   => $enquiries
        ]);
    }

    // Get Single Enquiry by ID
    public function getEnquiry($id = null)
    {
        $enquiryModel = new EnquiryModel();
        $enquiry = $enquiryModel->find($id);

        if ($enquiry) {
            return $this->respond([
                'status' => 'success',
                'data'   => $enquiry
            ]);
        }

        return $this->failNotFound('Inquiry not found.');
    }

    // Delete an Enquiry
    public function deleteEnquiry($id = null)
    {
        $enquiryModel = new EnquiryModel();
        if ($enquiryModel->delete($id)) {
            return $this->respondDeleted([
                'status'  => 'success',
                'message' => 'Inquiry deleted successfully!'
            ]);
        }

        return $this->failNotFound('Failed to delete Inquiry.');
    }
}
