<?php

namespace App\Controllers;

use CodeIgniter\RESTful\ResourceController;
use App\Models\EventsModel;

class EventController extends ResourceController
{
    
  public function getEvents($id = null)
{
    $eventModel = new EventsModel();

    if ($id) {
        // Fetch a single event
        $event = $eventModel->find($id);

        if (!$event) {
            return $this->failNotFound('Event not found');
        }

        return $this->respond([
            'status' => 'success',
            'data' => $event
        ]);
    }

    // Fetch all events in descending order
    $events = $eventModel->orderBy('id', 'DESC')->findAll();

    return $this->respond([
        'status' => 'success',
        'data' => $events
    ]);
}


    public function create()
    {
        $eventModel = new EventsModel(); // Load the model

        // Get form data
        $data = [
            'name'        => $this->request->getVar('name'),
            'date'        => $this->request->getVar('date'),
            'time'        => $this->request->getVar('time'),
            'type'        => $this->request->getVar('type'),
            'expiry_date' => $this->request->getVar('expiry_date'),
            'description' => $this->request->getVar('description'),
            'status'      => 'active',
        ];

        // Handle image upload
        $file = $this->request->getFile('image');
        if ($file && $file->isValid() && !$file->hasMoved()) {
            $newName = $file->getRandomName();
            $file->move('uploads/events', $newName);
            $data['image'] = base_url('uploads/events/' . $newName); // Store full URL
        }

        // Insert into database
        $eventModel->insert($data);

        return $this->respondCreated([
            'status'  => 'success',
            'message' => 'Event added successfully',
            'image'   => $data['image'] ?? null // Return image URL in response
        ]);
    }
    
    
    public function deleteEvent($id)
    {
        $eventModel = new EventsModel();
    
        // Check if event exists
        $event = $eventModel->find($id);
        if (!$event) {
            return $this->failNotFound('Event not found');
        }
    
        // Delete the event
        $eventModel->delete($id);
    
        return $this->respond([
            'status' => 'success',
            'message' => 'Event deleted successfully'
        ]);
    }
    
    public function getEventsAPP()
{
    $eventModel = new EventsModel();
    date_default_timezone_set('America/New_York'); // Example: New York Time

    // Get the current date
    $currentDate = date('Y-m-d');

    // Fetch all events from today onwards
    $events = $eventModel->where('date >=', $currentDate)->findAll();

    // Group events by date
    $groupedEvents = [];

    foreach ($events as $event) {
        $eventDate = date('j', strtotime($event['date']));
        $eventMonth = date('n', strtotime($event['date']));
        $eventYear = date('Y', strtotime($event['date']));

        $formattedEvent = [
            'image' => $event['image'],
            'type' => $event['type'],
            'event_name' => $event['name'],
            'description' => $event['description'],
            'id' => (int) $event['id'],
        ];

        $key = "{$eventDate}-{$eventMonth}-{$eventYear}";
        if (!isset($groupedEvents[$key])) {
            $groupedEvents[$key] = [
                'date' => (int) $eventDate,
                'month' => (int) $eventMonth,
                'year' => (int) $eventYear,
                'events' => [],
            ];
        }

        $groupedEvents[$key]['events'][] = $formattedEvent;
    }

    // Get single date if available, else return all
    $response = count($groupedEvents) === 1 ? array_values($groupedEvents)[0] : array_values($groupedEvents);

    return $this->respond([
        'status' => 'success',
        'data' => $response
    ]);
}


}
