<?php

namespace App\Controllers;

use CodeIgniter\RESTful\ResourceController;
use App\Models\FaqModel;

class FaqController extends ResourceController
{
    // Get All FAQs
    public function getFaqs()
    {
        $faqModel = new FaqModel();
        $faqs = $faqModel->where('status', 'active')->orderBy('created_at', 'DESC')->findAll();

        return $this->respond([
            'status' => 'success',
            'data' => $faqs
        ]);
    }

    // Create a new FAQ
    public function createFaq()
    {
        $faqModel = new FaqModel();

        // Get request data
        $data = [
            'question' => $this->request->getVar('question'),
            'answer'   => $this->request->getVar('answer'),
            'status'   => $this->request->getVar('status') ?? 'active',
        ];

        // Insert into database
        if ($faqModel->insert($data)) {
            return $this->respondCreated([
                'status'  => 'success',
                'message' => 'FAQ added successfully',
                'data'    => $data
            ]);
        }

        return $this->fail('Failed to add FAQ.');
    }

    // Delete an FAQ
    public function deleteFaq($id)
    {
        $faqModel = new FaqModel();
        $faq = $faqModel->find($id);

        if (!$faq) {
            return $this->failNotFound('FAQ not found.');
        }

        if ($faqModel->delete($id)) {
            return $this->respondDeleted([
                'status'  => 'success',
                'message' => 'FAQ deleted successfully'
            ]);
        }

        return $this->fail('Failed to delete FAQ.');
    }
}
