<?php

namespace App\Controllers;

use CodeIgniter\RESTful\ResourceController;
use App\Models\ImportantLinksModel;

class ImportantLinksController extends ResourceController
{
    protected $modelName = 'App\Models\ImportantLinksModel';
    protected $format    = 'json';

    // Fetch all links (ordered by position)
    public function index()
    {
        $links = $this->model->orderBy('position', 'ASC')->findAll();
        return $this->respond(['status' => 'success', 'data' => $links]);
    }

    // Add a new link
    public function create()
    {
        $rules = [
            'title' => 'required|max_length[255]',
            'url'   => 'required|valid_url|max_length[255]'
        ];

        if (!$this->validate($rules)) {
            return $this->failValidationErrors($this->validator->getErrors());
        }

        $data = [
            'title'    => $this->request->getPost('title'),
            'url'      => $this->request->getPost('url'),
            'position' => $this->model->countAll() + 1 // Auto set position
        ];

        $this->model->insert($data);

        return $this->respondCreated(['status' => 'success', 'message' => 'Link added successfully']);
    }

    // Update a link
    public function update($id = null)
    {
        $rules = [
            'title' => 'required|max_length[255]',
            'url'   => 'required|valid_url|max_length[255]'
        ];

        if (!$this->validate($rules)) {
            return $this->failValidationErrors($this->validator->getErrors());
        }

        if (!$this->model->find($id)) {
            return $this->failNotFound("Link not found");
        }

        $data = [
            'title' => $this->request->getPost('title'),
            'url'   => $this->request->getPost('url')
        ];

        $this->model->update($id, $data);

        return $this->respond(['status' => 'success', 'message' => 'Link updated successfully']);
    }

    // Delete a link
    public function delete($id = null)
    {
        if (!$this->model->find($id)) {
            return $this->failNotFound("Link not found");
        }

        $this->model->delete($id);

        return $this->respondDeleted(['status' => 'success', 'message' => 'Link deleted successfully']);
    }

    // Update link order
    public function updateOrder()
{
    $json = $this->request->getJSON(true); // Get JSON as array

    log_message('debug', 'Received update order request: ' . print_r($json, true)); // Debug log

    if (!isset($json['positions']) || !is_array($json['positions'])) {
        return $this->failValidationErrors(['positions' => 'Invalid format']); // Return error
    }

    foreach ($json['positions'] as $pos) {
        if (!isset($pos['id']) || !isset($pos['position']) || !is_numeric($pos['id']) || !is_numeric($pos['position'])) {
            return $this->failValidationErrors(['positions' => 'Missing or invalid id/position']);
        }

        $this->model->update($pos['id'], ['position' => $pos['position']]);
    }

    return $this->respond(['status' => 'success', 'message' => 'Order updated successfully']);
}

}
