<?php

namespace App\Controllers;

use App\Models\MayorNotesModel;
use CodeIgniter\RESTful\ResourceController;

class MayorNotesController extends ResourceController
{
    protected $modelName = 'App\Models\MayorNotesModel';
    protected $format    = 'json';

    /**
     * POST: Create a new mayor note
     */
    public function create()
{
    $validation = \Config\Services::validation();

    $validation->setRules([
        'title'         => 'required|string|max_length[255]',
        'mayor_message' => 'required|string',
        'video'         => 'permit_empty|uploaded[video]|max_size[video,10240]|ext_in[video,mp4,mov,avi,flv,wmv]',
        'video_url'     => 'permit_empty|valid_url'
    ]);

    if (!$this->validate($validation->getRules())) {
        return $this->failValidationErrors($validation->getErrors());
    }

    $title = $this->request->getPost('title');
    $mayorMessage = $this->request->getPost('mayor_message');
    $videoUrl = $this->request->getPost('video_url');
    $videoFile = $this->request->getFile('video');

    $videoPath = null;

    if (!empty($videoUrl)) {
        // If URL is provided, store it directly
        $videoPath = $videoUrl;
    } elseif ($videoFile && $videoFile->isValid() && !$videoFile->hasMoved()) {
        // If a video file is uploaded, store it in `uploads/videos/`
        $newName = $videoFile->getRandomName();
        $videoFile->move(FCPATH . 'uploads/videos', $newName); // Use FCPATH to ensure correct file path
        $videoPath = base_url('uploads/videos/' . $newName);  // Generate a URL path for the uploaded video
    }    

    // Log the data to check if all is fine
    log_message('debug', 'Data to insert: ' . print_r([
        'title'         => $title,
        'video_url'     => $videoPath,
        'mayor_message' => $mayorMessage,
    ], true));

    // Save to database
    $data = [
        'title'         => $title,
        'video_url'     => $videoPath,
        'mayor_message' => $mayorMessage,
    ];

    if ($this->model->insert($data)) {
        return $this->respondCreated([
            'status'  => 'success',
            'message' => 'Mayor note added successfully',
            'data'    => $data
        ]);
    } else {
        return $this->failServerError('Failed to insert data into the database.');
    }
}


    /**
     * GET: Fetch all mayor notes
     */
    public function index()
{
    $latestNote = $this->model->orderBy('id', 'DESC')->first();

    if (!$latestNote) {
        return $this->failNotFound('No mayor notes found.');
    }

    return $this->respond([
        'status'  => 'success',
        'message' => 'Latest mayor note retrieved successfully',
        'data'    => $latestNote
    ]);
}
    
}
