<?php

namespace App\Controllers;

use App\Models\NotificationModel;
use CodeIgniter\RESTful\ResourceController;
use DateTime; // Import the DateTime class

class NotificationController extends ResourceController
{
    protected $modelName = 'App\Models\NotificationModel';
    protected $format    = 'json';

    // GET API: Fetch all notifications
  public function index()
{
    // Fetch notifications in descending order
    $notifications = $this->model
        ->orderBy('id', 'DESC')
        ->findAll();

    // Check if there are notifications
    if (empty($notifications)) {
        return $this->respond([
            'status' => false,
            'message' => 'No notifications found',
            'data' => []
        ], 200);
    }

    // Format notifications with a readable timestamp
    foreach ($notifications as &$notification) {
        $dateTime = new DateTime($notification['created_at']);
        $notification['timestamp'] = $dateTime->format('d M Y h:i A'); // Example: "12 Feb 2025 06:00 AM"
    }

    // Return response
    return $this->respond([
        'status' => true,
        'message' => 'Notifications fetched successfully',
        'data' => $notifications
    ]);
}


    // POST API: Create a new notification
    public function create()
    {
        $body = $this->request->getVar('body');

        if (!$body) {
            return $this->respond([
                'status' => false,
                'message' => 'Body is required'
            ], 400);
        }

        $data = [
            'body' => $body
        ];

        $this->model->insert($data);

        return $this->respondCreated([
            'status' => true,
            'message' => 'Notification added successfully',
            'data' => $data
        ]);
    }
    
    
    // DELETE API: Delete a notification by ID
public function delete($id = null)
{
    $notification = $this->model->find($id);

    if (!$notification) {
        return $this->respond([
            'status' => false,
            'message' => 'Notification not found'
        ], 404);
    }

    $this->model->delete($id);

    return $this->respond([
        'status' => true,
        'message' => 'Notification deleted successfully'
    ]);
}

}
