<?php

namespace App\Controllers;

use App\Models\ResidentModel;
use CodeIgniter\RESTful\ResourceController;

class RegistrationController extends ResourceController
{
    // User Registration API
    public function register()
    {
        $residentModel = new ResidentModel();
        $validation = \Config\Services::validation();

        $data = [
            'first_name'   => $this->request->getVar('first_name'),
            'last_name'    => $this->request->getVar('last_name'),
            'email'        => $this->request->getVar('email'),
            'password'     => $this->request->getVar('password'),
            'phone_no'     => $this->request->getVar('phone_no'),
            'address'      => $this->request->getVar('address'),
            'city'         => $this->request->getVar('city'),
            'state'        => $this->request->getVar('state'),
            'zipcode'      => $this->request->getVar('zipcode'),
            'device'       => $this->request->getVar('device'),
            'coordinates'  => $this->request->getVar('coordinates') ?? '',
            'location'     => $this->request->getVar('location') ?? '',
            'ip'           => $this->request->getIPAddress(),
        ];

        log_message('debug', 'Register Data: ' . json_encode($data));

        $validation->setRules([
            'first_name'   => 'required|string|max_length[255]',
            'last_name'    => 'required|string|max_length[255]',
            'email'        => 'required|valid_email',
            'password'     => 'required|string|min_length[6]',
            'phone_no'     => 'required|string|max_length[20]',
            'device'       => 'required|string|max_length[255]',
        ]);

        if (!$this->validate($validation->getRules())) {
            return $this->failValidationErrors($validation->getErrors());
        }

        if ($residentModel->where('email', $data['email'])->first()) {
            return $this->response->setJSON([
                'status'  => '409',
                'code'    => 409,
                'message' => 'Email already exists. Please use a different email.',
            ])->setStatusCode(409);
        }
        
        if ($residentModel->where('phone_no', $data['phone_no'])->first()) {
            return $this->response->setJSON([
                'status'  => '409',
                'code'    => 409,
                'message' => 'Phone No already exists. Please use a different Phone No.',
            ])->setStatusCode(409);
        }


        $data['password'] = password_hash($data['password'], PASSWORD_BCRYPT);

        if ($residentModel->insert($data)) {
            return $this->respondCreated([
                'status'  => 'success',
                'message' => 'Your Registration is successful',
                'data'    => $data
            ]);
        } else {
            return $this->failServerError('Failed to register resident.');
        }
    }

   public function login()
{
    log_message('debug', "POST DATA: " . json_encode($this->request->getPost())); // Debugging

    $email = $this->request->getVar('email'); 
    $password = $this->request->getVar('password');

    if (!$email || !$password) {
        return $this->response->setJSON([
            'status' => 400,
            'code' => 400,
            'message' => 'Email and password are required.',
            'data' => null
        ])->setStatusCode(400);
    }

    $residentModel = new ResidentModel();
    $user = $residentModel->where('email', $email)->first();

    if (!$user || !password_verify($password, $user['password'])) {
        return $this->response->setJSON([
            'status' => 401,
            'code' => 401,
            'message' => 'Invalid email or password.',
            'data' => null
        ])->setStatusCode(401);
    }

    unset($user['password']); // Remove password for security

    // Generate API Token
    $token = bin2hex(random_bytes(32));

    return $this->response->setJSON([
        'status' => true,
        'code' => 200,
        'message' => 'Login successful!',
        'data' => [
            'token' => $token,
            'user' => $user
        ]
    ])->setStatusCode(200);
}


}
