<?php
namespace App\Libraries;

use Aws\Sns\SnsClient;
use Exception;

class SnsSms
{
    private $sns;

    public function __construct()
    {
        $this->sns = new SnsClient([
            'region'  => getenv('AWS_REGION'),
            'version' => 'latest',
            'credentials' => [
                'key'    => getenv('AWS_ACCESS_KEY_ID'),
                'secret' => getenv('AWS_SECRET_ACCESS_KEY'),
            ],
        ]);
    }

    public function sendSms($phoneNumber, $message)
    {
        try {
            $result = $this->sns->publish([
                'Message'     => $message,
                'PhoneNumber' => $phoneNumber,
                'MessageAttributes' => [
                    'AWS.SNS.SMS.SenderID' => [
                        'DataType' => 'String',
                        'StringValue' => getenv('AWS_SNS_SENDER_ID'),
                    ],
                    'AWS.SNS.SMS.SMSType' => [
                        'DataType' => 'String',
                        'StringValue' => 'Transactional', // Use 'Promotional' for marketing SMS
                    ],
                ],
            ]);

            return ['status' => 'success', 'messageId' => $result['MessageId']];
        } catch (Exception $e) {
            return ['status' => 'error', 'error' => $e->getMessage()];
        }
    }
}
