<?php

namespace App\Models;

use CodeIgniter\Model;

class ResidentModel extends Model
{
    protected $table = 'residents';
    protected $primaryKey = 'id';
    protected $allowedFields = [
        'first_name', 'last_name', 'email', 'password', 'phone_no', 
        'address', 'city', 'state', 'zipcode', 'ip', 'coordinates', 
        'device', 'location'
    ];
    
    // Automatically set the `created_at` and `updated_at` timestamps
    protected $useTimestamps = true;
    
    // Define the `created_at` and `updated_at` fields for automatic timestamp management
    protected $createdField  = 'created_at';
    protected $updatedField  = 'updated_at';
    
    // Validation rules for creating and updating records
    protected $validationRules = [
        'first_name'   => 'required|string|max_length[255]',
        'last_name'    => 'required|string|max_length[255]',
        'email'        => 'required|valid_email|is_unique[residents.email]',
        'password'     => 'required|string|min_length[6]',
        'phone_no'     => 'required|string|max_length[20]',
        'address'      => 'permit_empty|string',
        'city'         => 'permit_empty|string',
        'state'        => 'permit_empty|string',
        'zipcode'      => 'permit_empty|string',
        'device'       => 'permit_empty|string',
        'coordinates'  => 'permit_empty|string',
        'location'     => 'permit_empty|string',
    ];

    // Validation errors
    protected $validationMessages = [
        'email' => [
            'is_unique' => 'The email address has already been taken.',
        ],
        'password' => [
            'min_length' => 'The password must be at least 6 characters long.',
        ]
    ];

    // Custom function to check if an email already exists in the database
    public function checkEmailExists($email)
    {
        return $this->where('email', $email)->first(); // Returns the first record matching the email
    }
}
