<?= $this->include('dashboard/layout/header') ?>
<link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.4.2/css/all.min.css">

<style>
    .col-lg-6, .col-lg-12 { margin-top: 20px; }
    .btn-primary { margin-top: 25px !important; background: #e0a322 !important; }
    .table th, .table td { vertical-align: middle; text-align: left; cursor: pointer; }
    .delete-icon { color: red; cursor: pointer; transition: 0.3s; }
    .delete-icon:hover { color: darkred; transform: scale(1.2); }
    .loader { color: #e0a322; display: none; text-align: center; padding: 10px; }
    .pagination { display: flex; justify-content: center; margin-top: 20px; }
    .pagination button { margin: 0 5px; padding: 5px 10px; border: none; background: #e0a322; color: #fff; cursor: pointer; }
    .pagination button.active { background: darkred; }
    table {
        border-collapse: collapse;
        border-radius: 30px;
        border-style: hidden; /* hide standard table (collapsed) border */
        box-shadow: 0 0 0 1px #666; /* this draws the table border  */ 
    }
</style>

<div class="body-wrapper-inner bg-main">
    <div class="container mt-5">
        <h2 class="mb-4 pt-5 mt-5 text-center">Contacted Me - Inquiries</h2>
        <button class="btn btn-primary" onclick="fetchEnquiries()"><i class="fa fa-sync"></i> Refresh</button>
        <div class="loader" id="enquiryLoader"><i class="fa fa-spinner fa-spin"></i> Loading...</div>

        <div class="table-responsive mt-3">
            <table class="table table-bordered">
                <thead>
                    <tr>
                        <th onclick="sortTable(0)">#</th>
                        <th onclick="sortTable(1)">Full Name <i class="fa fa-sort"></i></th>
                        <th onclick="sortTable(2)">Phone <i class="fa fa-sort"></i></th>
                        <th onclick="sortTable(3)">Email</th>
                        <th onclick="sortTable(4)">Message</th>
                        <th onclick="sortTable(5)">IP Address</th>
                        <th onclick="sortTable(6)">Platform <i class="fa fa-sort"></i></th>
                        <th>Action</th>
                    </tr>
                </thead>
                <tbody id="enquiryTable"></tbody>
            </table>
        </div>
        <div class="pagination" id="pagination"></div>
    </div>
</div>

<script src="https://cdnjs.cloudflare.com/ajax/libs/jquery/3.6.0/jquery.min.js"></script>
<script>
    let enquiries = [];
    let currentPage = 1;
    const rowsPerPage = 10;
    let sortDirection = 1; // 1 = Ascending, -1 = Descending

    $(document).ready(function () {
        fetchEnquiries();
    });

    function fetchEnquiries() {
        $("#enquiryLoader").show();
        $.get('<?= site_url('api/enquiry/all') ?>', function (response) {
            $("#enquiryLoader").hide();
            if (response.status === 'success') {
                enquiries = response.data;
                displayTable();
                setupPagination();
            } else {
                $("#enquiryTable").html('<tr><td colspan="8" class="text-center">No enquiries found.</td></tr>');
            }
        }, "json");
    }

    function displayTable() {
        let table = $("#enquiryTable").html('');
        let start = (currentPage - 1) * rowsPerPage;
        let end = start + rowsPerPage;
        let paginatedItems = enquiries.slice(start, end);

        paginatedItems.forEach((enquiry, index) => {
            table.append(`
                <tr>
                    <td>${start + index + 1}</td>
                    <td>${enquiry.full_name}</td>
                    <td>${enquiry.phone_no}</td>
                    <td>${enquiry.email}</td>
                    <td>${enquiry.message}</td>
                    <td>${enquiry.ip}</td>
                    <td>${enquiry.platform}</td>
                    <td>
                        <i class="fa fa-trash delete-icon" onclick="deleteEnquiry(${enquiry.id})"></i>
                    </td>
                </tr>
            `);
        });
    }

    function setupPagination() {
        let totalPages = Math.ceil(enquiries.length / rowsPerPage);
        let pagination = $("#pagination").html('');

        if (totalPages > 1) {
            pagination.append(`<button onclick="changePage(-1)">«</button>`);

            for (let i = 1; i <= totalPages; i++) {
                pagination.append(`<button class="${i === currentPage ? 'active' : ''}" onclick="goToPage(${i})">${i}</button>`);
            }

            pagination.append(`<button onclick="changePage(1)">»</button>`);
        }
    }

    function goToPage(page) {
        currentPage = page;
        displayTable();
        setupPagination();
    }

    function changePage(direction) {
        if (currentPage + direction > 0 && currentPage + direction <= Math.ceil(enquiries.length / rowsPerPage)) {
            currentPage += direction;
            displayTable();
            setupPagination();
        }
    }

    function deleteEnquiry(id) {
        if (!confirm("Are you sure you want to delete this enquiry?")) return;

        $("#enquiryLoader").show();
        $.ajax({
            url: '<?= site_url('api/enquiry/') ?>' + id,
            type: 'DELETE',
            success: function (response) {
                $("#enquiryLoader").hide();
                if (response.status === 'success') {
                    alert("Enquiry Deleted");
                    enquiries = enquiries.filter(enquiry => enquiry.id !== id);
                    displayTable();
                    setupPagination();
                } else {
                    alert("Failed to delete enquiry.");
                }
            }
        });
    }

    function sortTable(columnIndex) {
        enquiries.sort((a, b) => {
            let valA = Object.values(a)[columnIndex];
            let valB = Object.values(b)[columnIndex];

            if (typeof valA === "string") valA = valA.toLowerCase();
            if (typeof valB === "string") valB = valB.toLowerCase();

            return (valA > valB ? 1 : -1) * sortDirection;
        });

        sortDirection *= -1;
        displayTable();
    }
</script>

<?= $this->include('dashboard/layout/footer') ?>
