<?= $this->include('dashboard/layout/header') ?>
<link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.4.2/css/all.min.css">

<style>
    .col-lg-6, .col-lg-12 { margin-top: 20px; }
    button.btn-primary.mt-3,.btn-primary { margin-top: 25px !important; background: #e0a322!important; }
    .table th, .table td { vertical-align: middle; text-align: left; }
    .table img { border-radius: 5px; width: 50px; }
    .delete-icon { color: red; cursor: pointer; transition: 0.3s; }
    .delete-icon:hover { color: darkred; transform: scale(1.2); }
    .loader { color: #e0a322; display: none; text-align: center; padding: 10px; }
    .modal-content { background: #0d0d0c; width: 50%; margin: 10% auto; padding: 20px; border-radius: 10px; border: 1px solid #e0a322; }
    .modal { display: none; position: fixed; z-index: 1000; left: 0; top: 0; width: 100%; height: 100%; background-color: rgba(0, 0, 0, 0.5); }
    .close { color: antiquewhite; position: absolute; right: 15px; top: 10px; font-size: 20px; cursor: pointer; }
    .form-group { flex: 1; display: flex; flex-direction: column; }
    input, select, textarea { width: 100%; border: 1px solid #ccc; padding: 8px; border-radius: 5px; }
    .btn-primary { background: #007bff; color: white; border: none; padding: 10px 20px; border-radius: 5px; cursor: pointer; }
    .btn-primary:hover { background: #0056b3; }
    #imagePreview { display: none; margin-top: 10px; width: 100px; border-radius: 5px; }
    label { color: antiquewhite; margin-bottom: 0px; }
</style>

<div class="body-wrapper-inner bg-main">
    <div class="container mt-5">
        <h2 class="mb-4 pt-5 mt-5 text-center">Manage FAQs</h2>
        <button class="btn-primary btn" onclick="openModal()"><i class="fa fa-plus"></i> Add FAQ</button>
        <div class="loader" id="faqLoader"><i class="fa fa-spinner fa-spin"></i> Loading...</div>

        <div class="table-responsive mt-3">
            <table class="table table-bordered">
                <thead>
                    <tr>
                        <th>#</th>
                        <th onclick="sortTable()" style="cursor: pointer;">
                            Question <span id="sortIcon"><i class="fa fa-sort"></i></span>
                        </th>
                        <th>Answer</th>
                        <th>Action</th>
                    </tr>
                </thead>
                <tbody id="faqTable"></tbody>
            </table>
        </div>
    </div>

    <!-- Modal for Adding FAQ -->
    <div id="faqModal" class="modal">
        <div class="modal-content p-5">
            <span class="close" onclick="closeModal()">&times;</span>
            <h3 class="text-center">Add New FAQ</h3>

            <form id="faqForm">
                <div class="row">
                    <div class="col-lg-12">
                        <div class="form-group">
                            <label>Question:</label><br>
                            <input type="text" id="faqQuestion" name="question" required>
                        </div>
                    </div>
                    <div class="col-lg-12">
                        <div class="form-group">
                            <label>Answer:</label><br>
                            <textarea id="faqAnswer" name="answer" rows="3" required></textarea>
                        </div>
                    </div>
                </div>
                <button type="submit" id="faqSubmitBtn" class="btn btn-primary">Submit</button>
                <span id="faqLoader" class="ms-2 text-primary fw-bold" style="display: none;">Saving...</span>
            </form>
        </div>
    </div>
</div>

<script src="https://cdnjs.cloudflare.com/ajax/libs/jquery/3.6.0/jquery.min.js"></script>
<script>
    let faqs = [];
    let sortAscending = true;

    $(document).ready(function () {
        fetchFAQs();

        $("#faqForm").on("submit", function (e) {
            e.preventDefault();
            addFAQ();
        });
    });

    function fetchFAQs() {
        $("#faqLoader").show();
        $.get('<?= site_url('api/faqs') ?>', function (response) {
            $("#faqLoader").hide();
            faqs = response.data;
            renderTable();
        }, "json");
    }

    function renderTable() {
        let table = $("#faqTable").html('');
        faqs.forEach((faq, index) => {
            table.append(`
                <tr>
                    <td>${index + 1}</td>
                    <td>${faq.question}</td>
                    <td>${faq.answer}</td>
                    <td>
                        <i class="fa fa-trash delete-icon" onclick="deleteFAQ(${faq.id})"></i>
                    </td>
                </tr>
            `);
        });
    }

    function addFAQ() {
        let formData = new FormData($("#faqForm")[0]);
        $("#faqSubmitBtn").prop("disabled", true).html("Saving...");
        $("#faqLoader").show();

        $.ajax({
            url: '<?= site_url('api/faqs/create') ?>',
            type: 'POST',
            data: formData,
            contentType: false,
            processData: false,
            success: function (response) {
                $("#faqLoader").hide();
                $("#faqSubmitBtn").prop("disabled", false).html("Submit");

                if (response.status === 'success') {
                    alert("FAQ added successfully!");
                    $("#faqForm")[0].reset();
                    closeModal();
                    fetchFAQs();
                } else {
                    alert("Error adding FAQ.");
                }
            },
            error: function () {
                $("#faqLoader").hide();
                $("#faqSubmitBtn").prop("disabled", false).html("Submit");
                alert("Something went wrong. Please try again.");
            }
        });
    }

    function deleteFAQ(id) {
        if (!confirm("Are you sure you want to delete this FAQ?")) return;

        $("#faqLoader").show();
        $.ajax({
            url: '<?= site_url('api/faqs/') ?>' + id,
            type: 'DELETE',
            success: function (response) {
                $("#faqLoader").hide();
                if (response.status === 'success') {
                    fetchFAQs();
                } else {
                    alert("Failed to delete FAQ.");
                }
            }
        });
    }

    function sortTable() {
        faqs.sort((a, b) => {
            return sortAscending
                ? a.question.localeCompare(b.question)
                : b.question.localeCompare(a.question);
        });

        sortAscending = !sortAscending;
        

        renderTable();
    }

    function openModal() { $("#faqModal").show(); }
    function closeModal() { $("#faqModal").hide(); $("#faqForm")[0].reset(); }
</script>
<?= $this->include('dashboard/layout/footer') ?>
