<?= $this->include('dashboard/layout/header') ?>
<link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.4.2/css/all.min.css">
<link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/jquery-ui/1.13.2/jquery-ui.min.css">

<!-- SortableJS (For Drag & Drop) -->
<script src="https://cdnjs.cloudflare.com/ajax/libs/Sortable/1.15.2/Sortable.min.js"></script>

<div class="body-wrapper-inner bg-main">
    <div class="container-fluid">
        <div class="row">
            <h2 class="mb-4">Manage Important Links</h2>

            <!-- Form to Add New Link -->
            <form id="linkForm" method="post">
                <div class="mb-3">
                    <label for="title" class="form-label">Title</label>
                    <input type="text" class="form-control" id="title" name="title" required>
                </div>
                <div class="mb-3">
                    <label for="url" class="form-label">URL</label>
                    <input type="url" class="form-control" id="url" name="url" required>
                </div>
                <button type="submit" class="btn btn-primary">Add Link</button>
            </form>

            <hr>

            <!-- Loader (Hidden by Default) -->
            <div id="loader" style="display: none; text-align: center;">
                <i class="fa fa-spinner fa-spin fa-2x"></i> Loading...
            </div>

            <!-- Table to Show Links -->
            <h3 class="mt-4">Stored Links</h3>
            <table class="table table-bordered">
                <thead>
                    <tr>
                        <th>Drag</th>
                        <th>#</th>
                        <th>Title</th>
                        <th>URL</th>
                        <th>Action</th>
                    </tr>
                </thead>
                <tbody id="linksTable">
                    <!-- Data will be inserted here via JavaScript -->
                </tbody>
            </table>
        </div>
    </div>
</div>

<!-- Custom Styles -->
<style>
    .sortable tr {
        cursor: grab;
    }
    .handle {
        cursor: grab;
    }
    .delete-icon {
        color: red;
        cursor: pointer;
    }
    #loader{
        color:#e0a322;
    }
</style>

<!-- jQuery & AJAX -->
<script src="https://cdnjs.cloudflare.com/ajax/libs/jquery/3.6.0/jquery.min.js"></script>

<script>
    $(document).ready(function () {
        fetchLinks(); // Fetch Links on Page Load

        $('#linkForm').on('submit', function (e) {
            e.preventDefault();
            addLink();
        });

        // Initialize SortableJS for Drag-and-Drop
        new Sortable(document.getElementById("linksTable"), {
            handle: ".handle",
            animation: 150,
            onEnd: function () {
                updateLinkOrder();
            }
        });
    });

    function fetchLinks() {
        $("#loader").show(); // Show Loader

        fetch('<?= site_url('api/important-links') ?>')
            .then(response => response.json())
            .then(data => {
                let table = $("#linksTable");
                table.html('');

                if (data.status === 'success') {
                    data.data.forEach((link, index) => {
                        let row = `
                            <tr data-id="${link.id}">
                                <td class="handle"><i class="fa fa-bars"></i></td>
                                <td>${index + 1}</td>
                                <td>${link.title}</td>
                                <td><a href="${link.url}" target="_blank">${link.url}</a></td>
                                <td><i class="fa fa-trash delete-icon" onclick="deleteLink(${link.id})"></i></td>
                            </tr>`;
                        table.append(row);
                    });
                }
            })
            .catch(error => console.error('Error fetching links:', error))
            .finally(() => {
                $("#loader").hide(); // Hide Loader after Fetching
            });
    }

    function addLink() {
        let formData = new FormData($('#linkForm')[0]);
        $("#loader").show(); // Show Loader when Adding

        fetch('<?= site_url('api/important-links') ?>', {
            method: 'POST',
            body: formData
        })
        .then(response => response.json())
        .then(data => {
            if (data.status === 'success') {
                alert('Link added successfully!');
                $('#linkForm')[0].reset();
                fetchLinks();
            } else {
                alert('Error adding link!');
            }
        })
        .catch(error => console.error('Error adding link:', error))
        .finally(() => {
            $("#loader").hide(); // Hide Loader after Adding
        });
    }

    function deleteLink(id) {
        if (!confirm("Are you sure you want to delete this link?")) return;

        $("#loader").show(); // Show Loader when Deleting

        fetch(`<?= site_url('api/important-links/') ?>${id}`, {
            method: 'DELETE'
        })
        .then(response => response.json())
        .then(data => {
            if (data.status === 'success') {
                alert('Link deleted successfully!');
                fetchLinks();
            } else {
                alert('Error deleting link!');
            }
        })
        .catch(error => console.error('Error deleting link:', error))
        .finally(() => {
            $("#loader").hide(); // Hide Loader after Deleting
        });
    }

    function updateLinkOrder() {
        let positions = [];

        $('#linksTable tr').each(function (index) {
            let id = $(this).attr('data-id');
            if (id) {
                positions.push({ id: parseInt(id), position: index + 1 });
            }
        });

        console.log("🚀 Sending positions:", JSON.stringify({ positions }));

        $("#loader").show(); // Show Loader when Updating Order

        fetch('<?= site_url('api/important-links/updateOrder') ?>', {
            method: 'POST',
            headers: { 'Content-Type': 'application/json' },
            body: JSON.stringify({ positions: positions })
        })
        .then(response => response.json())
        .then(data => {
            console.log("🔍 Response:", data);
            if (data.status === 'success') {
                fetchLinks(); // Fetch Links on Page Load
                alert('✅ Order updated successfully');
            } else {
                alert('❌ Error updating order: ' + JSON.stringify(data));
            }
        })
        .catch(error => console.error('❌ Error updating order:', error))
        .finally(() => {
            $("#loader").hide(); // Hide Loader after Updating
        });
    }
</script>

<?= $this->include('dashboard/layout/footer') ?>
