<?= $this->include('dashboard/layout/header') ?>

<link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.4.2/css/all.min.css">
<link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/bootstrap/4.6.2/css/bootstrap.min.css">

<style>
.modal-content { background: #1a1a19;    border: 1px solid #d89d22;
}
button.close { color: #fff; }
textarea#notificationMessage { background: transparent; }
.modal-header, .modal-footer { border: 0; }
.col-lg-6, .col-lg-12 { margin-top: 20px; }
.btn-primary { background: #e0a322 !important; }
.table th, .table td { vertical-align: middle; text-align: left; cursor: pointer; }
.delete-icon { color: red; cursor: pointer; transition: 0.3s; }
.delete-icon:hover { color: darkred; transform: scale(1.2); }
.loader { color: #e0a322; display: none; text-align: center; padding: 10px; }
.pagination { display: flex; justify-content: center; margin-top: 20px; }
.pagination button { margin: 0 5px; padding: 5px 10px; border: none; background: #e0a322; color: #fff; cursor: pointer; }
.pagination button.active { background: darkred; }
</style>

<div class="body-wrapper-inner bg-main">
    <div class="container mt-5">
        <h2 class="mb-4 pt-5 mt-5 text-center">Notifications</h2>
        <button class="btn btn-primary" data-toggle="modal" data-target="#notificationModal">
            <i class="fa fa-plus"></i> Create Notification
        </button>
        <button class="btn btn-primary" onclick="fetchNotifications()">
            <i class="fa fa-sync"></i> Refresh
        </button>
        <div class="loader" id="notificationLoader"><i class="fa fa-spinner fa-spin"></i> Loading...</div>

        <div class="table-responsive mt-3">
            <table class="table table-bordered">
                <thead>
                <tr>
                    <th>#</th>
                    <th>Message</th>
                    <th>SMS</th>
                    <th>Email</th>
                    <th>Action</th>
                </tr>
            </thead>
                <tbody id="notificationTable"></tbody>
            </table>
        </div>
        <div class="pagination" id="pagination"></div>
    </div>
</div>

<!-- Modal for Creating Notification -->
<div class="modal fade" id="notificationModal" tabindex="-1" aria-labelledby="notificationModalLabel" aria-hidden="true">
    <div class="modal-dialog">
        <div class="modal-content">
            <div class="modal-header">
                <h5 class="modal-title" id="notificationModalLabel">Create Notification</h5>
                <button type="button" class="close" data-dismiss="modal" aria-label="Close">
                    <span aria-hidden="true">&times;</span>
                </button>
            </div>
            <div class="modal-body">
                <textarea id="notificationMessage" class="form-control" rows="4" placeholder="Enter notification message"></textarea>
            </div>
            <div class="modal-footer">
                <button type="button" class="btn btn-primary" onclick="createNotification()">Create</button>
            </div>
        </div>
    </div>
</div>

<script src="https://code.jquery.com/jquery-3.6.0.min.js"></script>
<script src="https://cdnjs.cloudflare.com/ajax/libs/bootstrap/4.6.2/js/bootstrap.bundle.min.js"></script>

<script>
    let notifications = [];
    let currentPage = 1;
    const rowsPerPage = 10;

    $(document).ready(function () {
        fetchNotifications();
    });

    function fetchNotifications() {
        $("#notificationLoader").show();
        $.ajax({
            url: '<?= site_url('api/notifications') ?>',
            type: 'GET',
            dataType: 'json',
            success: function (response) {
                $("#notificationLoader").hide();
                if (response.status === true && Array.isArray(response.data)) {
                    notifications = response.data;
                    displayTable();
                    setupPagination();
                } else {
                    $("#notificationTable").html('<tr><td colspan="4" class="text-center">No notifications found.</td></tr>');
                }
            },
            error: function () {
                $("#notificationLoader").hide();
                alert("Failed to load notifications.");
            }
        });
    }

    function displayTable() {
        let table = $("#notificationTable").html('');
        let start = (currentPage - 1) * rowsPerPage;
        let end = start + rowsPerPage;
        let paginatedItems = notifications.slice(start, end);
    
        paginatedItems.forEach((notification, index) => {
            let smsUrl = '<?= base_url('content/notification/sms/') ?>' + notification.id;
            let emailUrl = '<?= base_url('content/notification/email/') ?>' + notification.id;
    
            table.append(`
                <tr id="row-${notification.id}">
                    <td>${start + index + 1}</td>
                    <td>${notification.body}</td>
                    <td class="text-center">
                        <a href="${smsUrl}" class="text-primary"><i class="fa fa-comment-dots"></i></a>
                    </td>
                    <td class="text-center">
                        <a href="${emailUrl}" class="text-success"><i class="fa fa-envelope"></i></a>
                    </td>
                    <td>
                        <button class="btn btn-danger btn-sm" onclick="deleteNotification(${notification.id})">
                            <i class="fa fa-trash"></i> Delete
                        </button>
                    </td>
                </tr>
            `);
        });
    }


    function setupPagination() {
        let totalPages = Math.ceil(notifications.length / rowsPerPage);
        let pagination = $("#pagination").html('');

        if (totalPages > 1) {
            pagination.append(`<button onclick="changePage(-1)">«</button>`);
            for (let i = 1; i <= totalPages; i++) {
                pagination.append(`<button class="${i === currentPage ? 'active' : ''}" onclick="goToPage(${i})">${i}</button>`);
            }
            pagination.append(`<button onclick="changePage(1)">»</button>`);
        }
    }

    function goToPage(page) {
        currentPage = page;
        displayTable();
        setupPagination();
    }

    function changePage(direction) {
        let newPage = currentPage + direction;
        if (newPage > 0 && newPage <= Math.ceil(notifications.length / rowsPerPage)) {
            currentPage = newPage;
            displayTable();
            setupPagination();
        }
    }

    function deleteNotification(id) {
        if (!confirm("Are you sure you want to delete this notification?")) return;
        $("#notificationLoader").show();

        $.ajax({
            url: '<?= site_url('api/notifications/') ?>' + id,
            type: 'DELETE',
            dataType: 'json',
            success: function (response) {
                $("#notificationLoader").hide();
                if (response.status === true) {
                    alert("Notification Deleted Successfully");
                    notifications = notifications.filter(notification => notification.id !== id);
                     fetchNotifications();
                    displayTable();
                    setupPagination();
                } else {
                    alert("Failed to delete notification.");
                }
            },
            error: function () {
                $("#notificationLoader").hide();
                alert("Error deleting notification.");
            }
        });
    }

    function createNotification() {
        let message = $("#notificationMessage").val().trim();
        if (!message) {
            alert("Please enter a notification message.");
            return;
        }

        $("#notificationLoader").show();
        $.ajax({
            url: '<?= site_url('api/notifications') ?>',
            type: 'POST',
            dataType: 'json',
            contentType: 'application/json',
            data: JSON.stringify({ body: message }),
            success: function (response) {
                $("#notificationLoader").hide();
                if (response.status === true) {
                    alert("Notification Created Successfully");
                    
                    // Append the new notification directly to the UI
                    let newNotification = { id: response.data.id, body: message };
                    notifications.unshift(newNotification); // Add to top of the list
                    displayTable();
                    setupPagination();

                    // Hide modal
                    $("#notificationMessage").val('');
                    $("#notificationModal").modal('hide');
                } else {
                    alert(response.message || "Failed to create notification.");
                }
            },
            error: function () {
                $("#notificationLoader").hide();
                alert("Error creating notification.");
            }
        });
    }
</script>


<?= $this->include('dashboard/layout/footer') ?>

